@@ -10,7 +10,15 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and limitations under the License.
 
-old_silence_get_record <- options("silence_named_get_record_warning" = TRUE)
+original_options <- options()
+
+options("silence_named_get_record_warning" = TRUE)
+
+##### To test on delivery/test versions of w[fm]s server change this option
+# options("bcdata.web_service_host" = "https://delivery.openmaps.gov.bc.ca")
+## OR
+# options("bcdata.web_service_host" = "https://test.openmaps.gov.bc.ca")
+
 
 point_record <- '76b1b7a3-2112-4444-857a-afccf7b20da8'
 polygon_record <- 'd1aff64e-dbfe-45a6-af97-582b7f6418b9'
